pygeodesy.units.Lat_

Package pygeodesy :: Module units :: Class Lat_ |
[frames] | no frames]

# Class Lat_

              object --+
                       |
                   float --+
                           |
          object --+       |
                   |       |
        named._Named --+   |
                       |   |
    unitsBase._NamedUnit --+
                           |
             unitsBase.Float --+
                               |
                         Degrees --+
                                   |
                            Degrees_ --+
                                       |
                                      Lat_

Named `float` representing a latitude in `degrees` within limits `low` and `high`.

Instance Methods
Inherited from `Degrees`: `toDegrees`, `toRadians`, `toRepr`, `toStr` Inherited from `unitsBase.Float`: `__repr__`, `__str__` Inherited from `float`: `__abs__`, `__add__`, `__coerce__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floordiv__`, `__format__`, `__ge__`, `__getattribute__`, `__getformat__`, `__getnewargs__`, `__gt__`, `__hash__`, `__int__`, `__le__`, `__long__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmod__`, `__rmul__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__setformat__`, `__sub__`, `__truediv__`, `__trunc__`, `as_integer_ratio`, `conjugate`, `fromhex`, `hex`, `is_integer` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, arg=None, name=`'``lat``'`, low=-90, high=90, **Error_name_arg) See Degrees_. |

Properties
Inherited from `float`: `imag`, `real` Inherited from `unitsBase._NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, arg=None, name=`'``lat``'`, low=-90, high=90, **Error_name_arg) Static Method |
See Degrees_. Arguments: `cls` - This class (`Degrees_` or sub-class). `arg` - The value (any `type` convertable to `float` or parsable by function parseDMS). `name` - Optional instance name (`str`). `low` - Optional lower `arg` limit (`float` or `None`). `high` - Optional upper `arg` limit (`float` or `None`). Returns: a new object with type S, a subtype of T A named `Degrees`. Raises: `Error` - Invalid `arg` or `arg` below `low` or above `high`. Overrides: object.__new__